@@ -4,5 +4,4 @@ from tests import app
 
 @app.route("/assert-regex")
 def assert_regex():
-    return 'Hello World!'
-
+    return "Hello World!"
