@@ -3,5 +3,4 @@ from tests import app
 
 @app.route("/capture-and-assert")
 def capture_and_assert():
-    return 'Hello World!'
-
+    return "Hello World!"
