@@ -4,10 +4,5 @@ from tests import app
 
 @app.route("/cookie_file")
 def cookie_file():
-    assert request.cookies['cookie1'] == 'valueA'
-    return ''
-
-
-
-
-
+    assert request.cookies["cookie1"] == "valueA"
+    return ""
