@@ -2,11 +2,12 @@ from tests import app
 from flask import make_response, request
 from io import BytesIO
 
+
 @app.route("/error-assert-bytearray")
 def error_assert_bytearray():
     result = BytesIO()
-    result.write(b'\xff')
+    result.write(b"\xff")
     data = result.getvalue()
     resp = make_response(data)
-    resp.content_type = 'application/octet-stream'
-    return resp
\ No newline at end of file
+    resp.content_type = "application/octet-stream"
+    return resp
