@@ -1,5 +1,6 @@
 from tests import app
 
+
 @app.route("/error-file-read-access")
 def error_file_read_access():
-    return ''
\ No newline at end of file
+    return ""
