@@ -1,5 +1,6 @@
 from tests import app
 
+
 @app.route("/error-invalid-xml")
 def error_invalid_xml():
-    return ''
\ No newline at end of file
+    return ""
